@@ -22,18 +22,16 @@ pub trait DnsModule {
     fn dns_proxy(&self, to: ManagedAddress) -> dns_proxy::Proxy<Self::Api>;
 
     #[payable("EGLD")]
+    #[only_owner]
     #[endpoint(dnsRegister)]
     fn dns_register(
         &self,
         dns_address: ManagedAddress,
         name: BoxedBytes,
         #[payment] payment: BigUint,
-    ) -> SCResult<AsyncCall> {
-        only_owner!(self, "only owner can call dnsRegister");
-
-        Ok(self
-            .dns_proxy(dns_address)
+    ) -> AsyncCall {
+        self.dns_proxy(dns_address)
             .register(name, payment)
-            .async_call())
+            .async_call()
     }
 }
